==> eagle-i-repository-webapp-1.1-MS4.00-sources.jar: org/eaglei/repository/servlet/WorkflowPush.java <==
package org.eaglei.repository.servlet;

import java.io.File;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;

import org.apache.log4j.Logger;
import org.apache.log4j.LogManager;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.apache.commons.fileupload.FileUploadException;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.disk.DiskFileItem;

import org.openrdf.OpenRDFException;
import org.openrdf.repository.RepositoryConnection;
import org.openrdf.repository.RepositoryException;
import org.openrdf.query.impl.DatasetImpl;
import org.openrdf.model.URI;
import org.openrdf.model.Value;
import org.openrdf.model.vocabulary.RDFS;
import org.openrdf.query.TupleQuery;
import org.openrdf.query.TupleQueryResult;
import org.openrdf.query.TupleQueryResultHandlerBase;
import org.openrdf.query.TupleQueryResultHandlerException;
import org.openrdf.query.BindingSet;
import org.openrdf.query.QueryLanguage;
import org.openrdf.query.MalformedQueryException;

import org.eaglei.repository.Access;
import org.eaglei.repository.View;
import org.eaglei.repository.workflow.Workflow;
import org.eaglei.repository.workflow.WorkflowTransition;
import org.eaglei.repository.vocabulary.REPO;
import org.eaglei.repository.vocabulary.DCTERMS;
import org.eaglei.repository.util.SPARQL;
import org.eaglei.repository.util.Utils;
import org.eaglei.repository.status.BadRequestException;
import org.eaglei.repository.status.InternalServerErrorException;
import org.eaglei.repository.status.ConflictException;
import org.eaglei.repository.status.NotFoundException;
import org.eaglei.repository.status.ForbiddenException;

/**
 * Servlet to invoke ("push") a workflow transition, on a specific instance.
 * Implementation logic is in the Workflow class.
 *
 * Args:
 *  uri - URI of the resource instance to push
 *  transition - URI of workflow transition to take
 *
 * @author Larry Stone
 * @version $Id: $
 * Started October 21, 2010
 */
public class WorkflowPush extends RepositoryServlet
{
    private static Logger log = LogManager.getLogger(WorkflowPush.class);

    /** {@inheritDoc} */
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
        throws ServletException, java.io.IOException
    {
        request.setCharacterEncoding("UTF-8");

        String rawURI = null;
        String rawTransition = null;

        // if we got here through POST with multipart, grovel through args
        if (ServletFileUpload.isMultipartContent(request)) {
            try {
                ServletFileUpload upload = new ServletFileUpload();
                File tmp = (File)getServletConfig().getServletContext().getAttribute("javax.servlet.context.tempdir");
                if (tmp == null)
                    throw new InternalServerErrorException("Cannot find servlet context attr = \"javax.servlet.context.tempdir\"");
                upload.setFileItemFactory(new DiskFileItemFactory(100000, tmp));
                for (DiskFileItem item : (List<DiskFileItem>)upload.parseRequest(request)) {
                    String ifn = item.getFieldName();
                    if (ifn.equals("transition"))
                        rawTransition = item.getString();
                    else if (ifn.equals("uri"))
                        rawURI = item.getString();
                    else
                        log.warn("Unrecoginized request argument: "+ifn);
                }
            } catch  (FileUploadException e) {
                log.error(e);
                throw new BadRequestException("failed parsing multipart request");
            }

        // gather args from input params instead
        } else {
            rawTransition = request.getParameter("transition");
            rawURI = request.getParameter("uri");
        }

        // defaulting and sanity-checking
        URI uri = Utils.parseURI(rawURI, "uri", true);
        URI transURI = Utils.parseURI(rawTransition, "transition", true);

        // this will fail if resource isn't visible to current user
        Workflow wf = Workflow.find(request, uri);
        if (log.isDebugEnabled())
            log.debug("PUSH PARAMETERS:\nresource="+uri+"\ntransition="+transURI);

        // this tests for existing claim, and access to the transition, etc.
        wf.invokeTransition(request, transURI);
        try {
            WithRepositoryConnection.get(request).commit();
        } catch (RepositoryException e) {
            throw new ServletException(e);
        }
    }
}

==> eagle-i-repository-webapp-1.2-MS2.01-sources.jar: org/eaglei/repository/servlet/WorkflowPush.java <==
package org.eaglei.repository.servlet;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;

import org.apache.log4j.Logger;
import org.apache.log4j.LogManager;

import org.openrdf.repository.RepositoryException;
import org.openrdf.model.URI;

import org.eaglei.repository.model.workflow.Workflow;

/**
 * Servlet to invoke ("push") a workflow transition, on a specific instance.
 * Implementation logic is in the Workflow class.
 *
 * Args:
 *  uri - URI of the resource instance to push
 *  transition - URI of workflow transition to take
 *
 * @author Larry Stone
 * @version $Id: $
 * Started October 21, 2010
 */
public class WorkflowPush extends RepositoryServlet
{
    private static Logger log = LogManager.getLogger(WorkflowPush.class);

    /** {@inheritDoc} */
    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
        throws ServletException, java.io.IOException
    {
        request.setCharacterEncoding("UTF-8");
        URI uri = getParameterAsURI(request, "uri", true);
        URI transURI = getParameterAsURI(request, "transition", true);

        // this will fail if resource isn't visible to current user
        Workflow wf = Workflow.find(request, uri);
        if (log.isDebugEnabled())
            log.debug("PUSH PARAMETERS:\nresource="+uri+"\ntransition="+transURI);

        // this tests for existing claim, and access to the transition, etc.
        wf.invokeTransition(request, transURI);
        try {
            WithRepositoryConnection.get(request).commit();
        } catch (RepositoryException e) {
            throw new ServletException(e);
        }
    }
}
